@@ -2,37 +2,9 @@ our $tests;
 
 use strict;
 use IO::Socket::INET;
-use Fcntl qw(:flock);
 no warnings;
 
-BEGIN {
-    # NOTE: the latest cpan smokers seem to run tests simultaneously, which
-    # completely breaks a ton of my tests.  Therefore, I'm doing this horrible
-    # thing.  If there is a better way, please tell it to me.
-
-    our @lock;
-    open my $lock, "<", $0 or die "error trying to open myself for locking purposes: $!";
-    flock $lock, LOCK_EX;
-
-    my ($o) = $0 =~ m/^(\d+)/;
-
-    sleep 1;
-
-    push @lock, $lock;
-    for my $i (sort glob "t/*.t") {
-        my ($i) = $0 =~ m/^(\d+)/;
-        next unless $i > $o;
-        open my $another_lock, "<", $0 or die "error trying to open myself for locking purposes: $!";
-        flock $another_lock, LOCK_EX;
-        push @lock, $another_lock;
-    }
-}
-
-BEGIN {
-    eval q [use lib 'inc'] # use our local copy of Net::IMAP::Server
-        unless $ENV{USE_SYSTEM_COPY};
-}
-
+use lib 'inc'; # use our local copy of Net::IMAP::Server
 for my $mod (qw(Coro::EV Net::IMAP::Server IO::Socket::SSL)) {
     my $res = do {
         # NOTE: the imap server emits various startup warnings on import
@@ -50,7 +22,7 @@ for my $mod (qw(Coro::EV Net::IMAP::Server IO::Socket::SSL)) {
 $SIG{CHLD} = $SIG{PIPE} = sub {};
 
 sub shutdown_imap_server {
-    if( my $imapfh = IO::Socket::INET->new('localhost:19794') ) {
+    if( my $imapfh = IO::Socket::INET->new('localhost:7000') ) {
         print $imapfh "1 Shutdown\n";
     }
 }
@@ -77,7 +49,7 @@ if( my $pid = fork ) {
     $retries = 10;
 
     my $line; {
-        sleep 1 while (--$retries)>0 and not $imapfh = IO::Socket::INET->new('localhost:19794');
+        sleep 1 while (--$retries)>0 and not $imapfh = IO::Socket::INET->new('localhost:7000');
 
         if( not $imapfh ) {
             warn "unable to start Net::IMAP::Server, skipping all meaningful tests\n";
@@ -89,22 +61,15 @@ if( my $pid = fork ) {
         redo unless $line =~ m/OK/;
     };
 
-    my $file = $INC{'Net/IMAP/Server.pm'};
-    my $ver  = $Net::IMAP::Server::VERSION;
-
     chomp $line;
-    $line =~ s/(\* OK).*/$1 $file ($ver)/;
-
     my $len = length $line; $len ++;
-    print STDERR "\e7\e[5000C\e[${len}D$line\e8" unless $ENV{AUTOMATED_TESTING};
+    print STDERR "\e7\e[5000C\e[${len}D$line\e8";
     close $imapfh;
 
     $0 = "Net::IMAP::Simple($$)";
 
     if( __PACKAGE__->can('run_tests') ) {
-        my $res = eval { run_tests(); 7_7};
-
-        warn "\n\nERROR running tests: $@\n\n" if $res != 7_7;
+        run_tests()
 
     } else {
         warn "\nserver started in standalone testing mode...\n";
@@ -141,17 +106,12 @@ if( my $pid = fork ) {
     # (we don't really care if the above fails...)
 
     use t::Shutdown;
-    use t::CanFlag;
     Net::IMAP::Server->new(
-        port             => 19794,
-        ssl_port         => 19795,
+        port             => 7000,
+        ssl_port         => 8000,
         auth_class       => "t::Auth",
         model_class      => "t::Model",
         connection_class => "t::Connection",
-
-        log_file  => "formal-imap-server.log",
-        log_level => 4
-
     )->run;
 }
 
